@@ -40,7 +40,7 @@ use vars qw($VERSION);
 
 use strict;
 
-$VERSION = '19.0';
+$VERSION = '19.1';
 
 # SDO_ETYPE
 # Second element of triplet in SDO_ELEM_INFO
@@ -803,7 +803,10 @@ sub setCoordicates
 	$end = $#{$coords} + 1 if ($end <= 0);
 
 	for (my $i = $start - 1; $i < $end && ($i <= $#{$coords}); $i++) {
-		$str .= join(' ', @{$coords->[$i]}) . ', ';
+		my $coordinates = join(' ', @{$coords->[$i]});
+		if ($coordinates =~ /\d/) {
+			$str .= "$coordinates, ";
+		}
 	}
 	$str =~ s/, $//;
 
